@@ -19,7 +19,7 @@ from .errors import LaspyException
 from .point import dims
 from .point.format import PointFormat, ExtraBytesParams
 from .point.record import PackedPointRecord
-from .utils import read_string, write_as_c_string
+from .utils import read_string, write_string
 from .vlrs import VLR
 from .vlrs.geotiff import create_geotiff_projection_vlrs
 from .vlrs.known import (
@@ -252,7 +252,13 @@ class LasHeader:
         #: The number of evlrs in the file
         self.number_of_evlrs: int = 0
 
-        # Info we keep because its useful for us but not the user
+        #: EVLRs, even though they are not stored in the 'header'
+        #: part of the file we keep them in this class
+        #: as they contain same information as vlr.
+        #: None when the file does not support EVLR
+        self.evlrs: Optional[VLRList] = None
+
+        # Info we keep because it's useful for us but not the user
         self.offset_to_point_data: int = 0
         self.are_points_compressed: bool = False
 
@@ -417,8 +423,10 @@ class LasHeader:
             This requires `pyproj`.
 
         .. warning::
-            Not all CRS are supported when adding GeoTiff tags. For example, custom
-            CRS. Typically, if the CRS has an EPSG code it will be supported.
+            Not all CRS are supported when adding GeoTiff tags.
+            For example, custom CRS.
+
+            Typically, if the CRS has an EPSG code it will be supported.
         """
         import pyproj
 
@@ -518,11 +526,22 @@ class LasHeader:
         self.are_points_compressed = state
 
     @classmethod
-    def read_from(cls, stream: BinaryIO) -> "LasHeader":
+    def read_from(
+        cls, original_stream: BinaryIO, read_evlrs: bool = False
+    ) -> "LasHeader":
+        """
+        Reads the header from the stream
+
+        read_evlrs: If true, evlrs will be read
+
+        Leaves the stream pos right before the point starts
+        (regardless of is read_evlrs was true)
+
+        """
         little_endian = "little"
         header = cls()
 
-        stream = io.BytesIO(cls._prefetch_header_data(stream))
+        stream = io.BytesIO(cls._prefetch_header_data(original_stream))
 
         file_sig = stream.read(4)
         # This should not be possible as _prefetch already checks this
@@ -651,6 +670,10 @@ class LasHeader:
                 f"header says {point_size} point_format created says {point_format.size}"
             )
 
+        if read_evlrs:
+            header.read_evlrs(original_stream)
+            stream.seek(header.offset_to_point_data)
+
         return header
 
     def write_to(
@@ -688,7 +711,7 @@ class LasHeader:
         stream.write(self.version.major.to_bytes(1, little_endian, signed=False))
         stream.write(self.version.minor.to_bytes(1, little_endian, signed=False))
 
-        was_truncated = write_as_c_string(
+        was_truncated = write_string(
             stream,
             self.system_identifier,
             SYSTEM_IDENTIFIER_LEN,
@@ -700,7 +723,7 @@ class LasHeader:
                 f" it will be truncated"
             )
 
-        was_truncated = write_as_c_string(
+        was_truncated = write_string(
             stream,
             self.generating_software,
             GENERATING_SOFTWARE_LEN,
@@ -793,12 +816,46 @@ class LasHeader:
 
         geo_vlr = self._vlrs.get_by_id("LASF_Projection")
 
+        if self.evlrs is not None:
+            geo_vlr.extend(self.evlrs.get_by_id("LASF_Projection"))
+
         for rec in geo_vlr:
             if isinstance(rec, (WktCoordinateSystemVlr, GeoKeyDirectoryVlr)):
-                return rec.parse_crs()
+                crs = rec.parse_crs()
+                if crs is not None:
+                    return crs
 
         return None
 
+    def read_evlrs(self, stream):
+        """
+        Reads EVLRs from the stream and sets them in the
+        data property.
+
+        The evlrs are accessed from the `evlrs` property
+
+        Does nothing if either of these is true:
+            - The file does not support EVLRS (version < 1.4)
+            - The file has no EVLRS
+            - The stream does not support seeking
+
+        Leaves/restores the stream position to where it was before the call
+        """
+        if self.version.minor >= 4:
+            if self.number_of_evlrs > 0 and stream.seekable():
+                saved_pos = stream.tell()
+                stream.seek(self.start_of_first_evlr, io.SEEK_SET)
+                self.evlrs = VLRList.read_from(
+                    stream, self.number_of_evlrs, extended=True
+                )
+                stream.seek(saved_pos)
+            elif self.number_of_evlrs > 0 and not stream.seekable():
+                self.evlrs = None
+            else:
+                self.evlrs = VLRList()
+        else:
+            self.evlrs = None
+
     @staticmethod
     def _prefetch_header_data(source) -> bytes:
         """
