@@ -71,6 +71,13 @@ class LasWriter:
         self.closefd = closefd
         self.encoding_errors = encoding_errors
         self.header = deepcopy(header)
+        # The point writer will take take of creating and writing
+        # the correct laszip vlr, however we have to make sure
+        # no prior laszip vlr exists
+        try:
+            self.header.vlrs.pop(header.vlrs.index("LasZipVlr"))
+        except ValueError:
+            pass
         self.header.partial_reset()
 
         self.dest = dest
@@ -208,9 +215,9 @@ class LasWriter:
                 last_error = e
 
         if last_error is not None:
-            raise LaspyException("No LazBackend selected, cannot compress")
-        else:
             raise LaspyException(f"No LazBackend could be initialized: {last_error}")
+        else:
+            raise LaspyException("No LazBackend selected, cannot compress")
 
     def __enter__(self):
         return self
